@@ -1,5 +1,3 @@
 from .report import Report
 
-__all__ = [
-    "Report"
-]
+__all__ = ["Report"]
